@@ -155,129 +155,144 @@ c     - store block i
                imoms(i)=1
                ii1=(i-1)*leng+1
                ii2=i*leng
-               do 210 j=1,ps
+               do j=1,ps
                   moms(i,1,j)=0d0
- 210              moms(i,2,j)=0d0
+                  moms(i,2,j)=0d0
+               end do
                tt=0d0
                xx=0d0
-               do 220 ii=ii1,ii2
+               do ii=ii1,ii2
                   tt=tt+to(ii)
- 220              xx=xx+x(ii)
+                  xx=xx+x(ii)
+               end do
                tt=tt/leng
                xx=xx/leng
                moms(i,1,0)=tt
                moms(i,2,0)=xx
-               do 240 ii=ii1,ii2
+               do ii=ii1,ii2
                   xy=x(ii)-xx
-                  do 230 j=1,p+2
+                  do j=1,p+2
                      xy=xy*(to(ii)-tt)
- 230                 moms(i,1,j)=moms(i,1,j)+xy
+                     moms(i,1,j)=moms(i,1,j)+xy
+                  end do
                   xy=to(ii)-tt
-                  do 240 j=2,ps
+                  do j=2,ps
                      xy=xy*(to(ii)-tt)
- 240                 moms(i,2,j)=moms(i,2,j)+xy
-               endif
-c
-               n1=n
-               n=n+leng
-               d=tbar
-               e=xbar
-               tbar=tbar+(moms(i,1,0)-tbar)*leng/n
-               xbar=xbar+(moms(i,2,0)-xbar)*leng/n
-               d=d-tbar
-               e=e-xbar
-               nn=-n1/leng
-               do 320 j=p+2,1,-1
-                  dp=1d0
-                  dnp=1d0
-                  tx=0d0
-                  do 310 k=j,1,-1
-                     tx=tx+bin(j,k)*(t(k)+e*s(k)
-     .                    +dnp*(moms(i,1,k)+nn*e*moms(i,2,k)))*dp
-                     dp=dp*d
- 310                 dnp=dnp*nn
- 320              t(j)=tx+e*dp*n1*(1d0-dnp)
-C
-               do 340 j=ps,2,-1
-                  dnp=1d0
-                  dp=1d0
-                  sx=0d0
-                  do 330 k=j,2,-1
-                     sx=sx+bin(j,k)*(s(k)+dnp*moms(i,2,k))*dp
-                     dp=dp*d
- 330                 dnp=dnp*nn
-                  dp=dp*d
- 340              s(j)=sx+dp*n1*(1d0-dnp)
- 480        continue
-         endif
-c
-c     compute last incomplete block without storing
-c
-         if(io.ge.i2) then
-            tt=0d0
-            xx=0d0
-            n2=io-i2+1
-            do 510 i=i2,io
-               tt=tt+to(i)
- 510           xx=xx+x(i)
-            tt=tt/n2
-            xx=xx/n2
-            do 520 j=1,ps
-               mom(1,j)=0d0
- 520           mom(2,j)=0d0
-            do 540 i=i2,io
-               xy=x(i)-xx
-               do 530 j=1,p+2
-                  xy=xy*(to(i)-tt)
- 530              mom(1,j)=mom(1,j)+xy
-               xy=to(i)-tt
-               do 540 j=2,ps
-                  xy=xy*(to(i)-tt)
- 540              mom(2,j)=mom(2,j)+xy
-c
-               n1=n
-               n=n+n2
-               d=tbar
-               e=xbar
-               tbar=tbar+(tt-tbar)*n2/n
-               xbar=xbar+(xx-xbar)*n2/n
-               d=d-tbar
-               e=e-xbar
-               nn=-n1/n2
-               do j=p+2,1,-1
-                  dp=1d0
-                  dnp=1d0
-                  tx=0d0
-                  do k=j,1,-1
-                     tx=tx+bin(j,k)*(t(k)+e*s(k)
-     .                    +dnp*(mom(1,k)+nn*e*mom(2,k)))*dp
-                     dp=dp*d
-                     dnp=dnp*nn
+                     moms(i,2,j)=moms(i,2,j)+xy
                   end do
-                  t(j)=tx+e*dp*n1*(1d0-dnp)
-               end do
-C
-               do j=ps,2,-1
-                  dnp=1d0
-                  dp=1d0
-                  sx=0d0
-                  do  k=j,2,-1
-                     sx=sx+bin(j,k)*(s(k)+dnp*mom(2,k))*dp
-                     dp=dp*d
-                     dnp=dnp*nn
-                  end do
-                  dp=dp*d
-                  s(j)=sx+dp*n1*(1d0-dnp)
                end do
             endif
 c
-            s(0)=dble(n)
+            n1=n
+            n=n+leng
+            d=tbar
+            e=xbar
+            tbar=tbar+(moms(i,1,0)-tbar)*leng/n
+            xbar=xbar+(moms(i,2,0)-xbar)*leng/n
+            d=d-tbar
+            e=e-xbar
+            nn=-n1/leng
+            do j=p+2,1,-1
+               dp=1d0
+               dnp=1d0
+               tx=0d0
+               do k=j,1,-1
+                  tx=tx+bin(j,k)*(t(k)+e*s(k)
+     .                 +dnp*(moms(i,1,k)+nn*e*moms(i,2,k)))*dp
+                  dp=dp*d
+                  dnp=dnp*nn
+               end do
+               t(j)=tx+e*dp*n1*(1d0-dnp)
+            end do
+C
+            do j=ps,2,-1
+               dnp=1d0
+               dp=1d0
+               sx=0d0
+               do k=j,2,-1
+                  sx=sx+bin(j,k)*(s(k)+dnp*moms(i,2,k))*dp
+                  dp=dp*d
+                  dnp=dnp*nn
+               end do
+               dp=dp*d
+               s(j)=sx+dp*n1*(1d0-dnp)
+            end do
+ 480     continue
+      endif
+c
+c     compute last incomplete block without storing
+c
+      if(io.ge.i2) then
+         tt=0d0
+         xx=0d0
+         n2=io-i2+1
+         do i=i2,io
+            tt=tt+to(i)
+            xx=xx+x(i)
+         end do
+         tt=tt/n2
+         xx=xx/n2
+         do j=1,ps
+            mom(1,j)=0d0
+            mom(2,j)=0d0
+         end do
+         do i=i2,io
+            xy=x(i)-xx
+            do j=1,p+2
+               xy=xy*(to(i)-tt)
+               mom(1,j)=mom(1,j)+xy
+            end do
+            xy=to(i)-tt
+            do j=2,ps
+               xy=xy*(to(i)-tt)
+               mom(2,j)=mom(2,j)+xy
+            end do
+         end do
+c
+         n1=n
+         n=n+n2
+         d=tbar
+         e=xbar
+         tbar=tbar+(tt-tbar)*n2/n
+         xbar=xbar+(xx-xbar)*n2/n
+         d=d-tbar
+         e=e-xbar
+         nn=-n1/n2
+         do j=p+2,1,-1
+            dp=1d0
+            dnp=1d0
+            tx=0d0
+            do k=j,1,-1
+               tx=tx+bin(j,k)*(t(k)+e*s(k)
+     .              +dnp*(mom(1,k)+nn*e*mom(2,k)))*dp
+               dp=dp*d
+               dnp=dnp*nn
+            end do
+            t(j)=tx+e*dp*n1*(1d0-dnp)
+         end do
+C
+         do j=ps,2,-1
+            dnp=1d0
+            dp=1d0
+            sx=0d0
+            do  k=j,2,-1
+               sx=sx+bin(j,k)*(s(k)+dnp*mom(2,k))*dp
+               dp=dp*d
+               dnp=dnp*nn
+            end do
+            dp=dp*d
+            s(j)=sx+dp*n1*(1d0-dnp)
+         end do
+      endif
+c
+      s(0)=dble(n)
 c     write(*,'(5g12.4)')(t(i),i=0,ps)
 c     write(*,'(5g12.4)')(s(i),i=0,ps)
 c
-            return
-            end
+      return
+      end
 C     ---
+
       SUBROUTINE lpslv(A,D,y,NA,NSIN,nzer,SINout,sin,ZER,dif)
 
 ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
@@ -304,59 +319,64 @@ C
 C     CHOLESKY-DECOMPOSITION
 c
       NSIN=0
-      DO 130 II=1,NA
+      DO II=1,NA
          D(II)=A(II,II)
          NN1=II-1
-         IF (NN1) 100,100,30
- 30      DO JJ=1,NN1
+         IF (NN1 > 0) then
+            DO JJ=1,NN1
             XX=A(JJ,II)
             NN2=JJ-1
-            IF (NN2) 60,60,40
- 40         DO KK=1,NN2
-               XX=XX-A(II,KK)*A(JJ,KK)*D(KK)
-            end do
- 60         YY=0D0
-            IF (D(JJ)-ZER) 80,80,70
- 70         YY=XX/D(JJ)
- 80         D(II)=D(II)-XX*YY
+            IF (NN2 > 0) then
+               DO KK=1,NN2
+                  XX=XX-A(II,KK)*A(JJ,KK)*D(KK)
+               end do
+            end if
+            YY=0D0
+            IF (D(JJ)-ZER > 0) YY=XX/D(JJ)
+            D(II)=D(II)-XX*YY
             A(II,JJ)=YY
          end do
- 100     IF (D(II)-A(II,II)*SIN) 110,110,130
- 110     D(II)=0D0
+      end if
+      if (D(II)-A(II,II)*SIN <= 0) then
+         D(II)=0D0
          NSIN=NSIN+1
- 130  CONTINUE
+      endif
+      end do
       sinout=d(na)/a(na,na)
 C
 C     SOLUTION OF LINEAR EQUATION
 C
       NZER=0
-      IF (NA-1) 300,300,210
- 210  DO 230 II=2,NA
-         NN1=II-1
-         DO 220 KK=1,NN1
-            Y(II)=Y(II)-A(II,KK)*Y(KK)
- 220     CONTINUE
- 230  CONTINUE
+      IF (NA >= 2) then
+         DO II=2,NA
+            NN1=II-1
+            DO KK=1,NN1
+               Y(II)=Y(II)-A(II,KK)*Y(KK)
+            end do
+         end do
+      end if
+
 c     - compute only last dif elements
- 300  DO 390 II=1,dif
+      DO II=1,dif
          JJ=NA+1-II
          XX=0D0
-         IF (D(JJ)-ZER) 320,320,310
- 310     XX=Y(JJ)/D(JJ)
- 320     IF (D(JJ)-ZER) 330,330,350
- 330     IF (D(JJ)) 340,350,340
- 340     NZER=NZER+1
- 350     NN1=JJ+1
-         IF (NA-NN1) 380,360,360
- 360     DO 370 KK=NN1,NA
-            XX=XX-A(KK,JJ)*Y(KK)
- 370     CONTINUE
- 380     Y(JJ)=XX
- 390  CONTINUE
+         IF (D(JJ) > ZER) XX=Y(JJ)/D(JJ)
+         IF (D(JJ) <= ZER) then
+            IF (D(JJ) .ne. 0) NZER=NZER+1
+         end if
+         NN1=JJ+1
+         IF (NA >= NN1) then
+            DO KK=NN1,NA
+               XX=XX-A(KK,JJ)*Y(KK)
+            end do
+         end if
+         Y(JJ)=XX
+      end do
 C
       RETURN
       END
 C     ---
+
       subroutine lpsub(t,s,to,x,tbar,xbar,p,pmax,n,bin,iu,io)
 
 ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
@@ -450,26 +470,27 @@ ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 C
 C     SOLUTION OF LINEAR EQUATION
 C
-      IF (NA-1) 300,300,210
- 210  DO II=2,NA
-         NN1=II-1
-         DO KK=1,NN1
-            Y(II)=Y(II)-A(II,KK)*Y(KK)
+      IF (NA >= 2) then
+         DO II=2,NA
+            NN1=II-1
+            DO KK=1,NN1
+               Y(II)=Y(II)-A(II,KK)*Y(KK)
+            end do
          end do
-      end do
+      end if
 
 c     - compute only last dif elements
- 300  DO II=1,dif
+      DO II=1,dif
          JJ=NA+1-II
          XX=0D0
-         IF (D(JJ)-ZER) 350,350,310
- 310     XX=Y(JJ)/D(JJ)
- 350     NN1=JJ+1
-         IF (NA-NN1) 380,360,360
- 360     DO KK=NN1,NA
-            XX=XX-A(KK,JJ)*Y(KK)
-         end do
- 380     Y(JJ)=XX
+         IF (D(JJ) > ZER) XX=Y(JJ)/D(JJ)
+         NN1=JJ+1
+         IF (NA >= NN1) then
+            DO KK=NN1,NA
+               XX=XX-A(KK,JJ)*Y(KK)
+            end do
+         end if
+         Y(JJ)=XX
       end do
 C
       RETURN
